@@ -9,6 +9,8 @@ from aio.core import event
 from aio.core.directory import ADirectory
 from aio.core.functional import async_property
 
+from envoy.base import utils
+
 
 @abstracts.implementer(event.IExecutive)
 class ACodeCheck(event.AExecutive, metaclass=abstracts.Abstraction):
@@ -49,3 +51,14 @@ class AFileCodeCheck(ACodeCheck, metaclass=abstracts.Abstraction):
     async def problem_files(self) -> Dict[str, List[str]]:
         """Discovered files with flake8 errors."""
         raise NotImplementedError
+
+
+class AProjectCodeCheck(ACodeCheck,  metaclass=abstracts.Abstraction):
+
+    def __init__(
+            self,
+            project: utils.interface.IProject,
+            *args,
+            **kwargs) -> None:
+        self.project = project
+        super().__init__(project.directory, *args, **kwargs)
